@@ -7,7 +7,8 @@ class RelatedParty(CamelModel):
     partner_name: str
     contact_method: str
     contact_email: Optional[str] = None
-    province_full_coverage: Optional[list[str]] = None
+    province_full_coverage: Optional[bool] = True
+    city_coverage: Optional[bool] = False
 
 
 class CityCoverageProcessedJob(AddressProcessingJob):
