@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Optional, Literal
+from typing import Optional, Literal, List
 
 from fastapi_camelcase import CamelModel
 from pydantic import Field
@@ -16,6 +16,7 @@ class Place(CamelModel):
 
 class PlaceAMS(Place):
     city: Optional[str] = None
+    city_aliases: Optional[List[str]] = None
     country: Literal["USA", "CAN"] = "CAN"
     postcode: Optional[str] = None
     state_or_province: Optional[str] = None
