@@ -6,8 +6,8 @@ T = TypeVar("T")
 
 
 class PageDto(CamelModel):
-    def __init__(self, data: List[T], pagination_metadata: PageMetaDto):
-        super().__init__(data=data, pagination_metadata=pagination_metadata)
+    def __init__(self, data: List[T], meta: PageMetaDto):
+        super().__init__(data=data, meta=meta)
 
     data: List[T]
-    pagination_metadata: PageMetaDto
+    meta: PageMetaDto
